@@ -3,7 +3,7 @@ package Prty;
 use strict;
 use warnings;
 
-our $VERSION = 1.104;
+our $VERSION = 1.105;
 
 =encoding utf8
 
@@ -284,6 +284,18 @@ L<Prty::Html::Widget::TextField> - Einzeiliges Textfeld
 
 =item *
 
+L<Prty::Http::Client> - HTTP-Client
+
+=item *
+
+L<Prty::Http::Cookie> - HTTP-Cookie
+
+=item *
+
+L<Prty::Http::Message> - HTTP-Nachricht
+
+=item *
+
 L<Prty::Image> - Operationen im Zusammenhang mit Bildern/Bilddateien
 
 =item *
@@ -496,10 +508,18 @@ L<Prty::SoapWsdlServiceCgi::Demo> - Demo für SOAP Web Service
 
 =item *
 
+L<Prty::Socket> - TCP-Verbindung zu einem Server
+
+=item *
+
 L<Prty::Sql> - Klasse zur Generierung von SQL
 
 =item *
 
+L<Prty::SqlPlus> - Erzeugung von SQL*Plus Code
+
+=item *
+
 L<Prty::Stacktrace> - Generiere und visualisiere einen Stacktrace
 
 =item *
@@ -536,6 +556,10 @@ L<Prty::Time> - Klasse zur Repräsentation von Datum und Uhrzeit
 
 =item *
 
+L<Prty::Time::RFC822> - Erzeuge Zeitangabe nach RFC 822
+
+=item *
+
 L<Prty::TimeLapse::Directory> - Bildsequenz-Verzeichnis
 
 =item *
@@ -556,17 +580,25 @@ L<Prty::TimeLapse::Sequence> - Bildsequenz
 
 =item *
 
+L<Prty::Timeseries::Synchronizer> - Rasterung/Synchronisation von Zeitreihen
+
+=item *
+
 L<Prty::Udl> - Universal Database Locator
 
 =item *
 
 L<Prty::Unindent> - Entferne Einrückung von "Here Document" oder String-Literal
 
+=item *
+
+L<Prty::Url> - URL Klasse
+
 =back
 
 =head1 VERSION
 
-1.104
+1.105
 
 =head1 AUTHOR
 
