@@ -5,8 +5,9 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.104;
+our $VERSION = 1.105;
 
+use POSIX ();
 use Time::Local ();
 
 # -----------------------------------------------------------------------------
@@ -118,6 +119,70 @@ sub germanToProgramNumber {
 
 # -----------------------------------------------------------------------------
 
+=head3 intToWord() - Wandele positive ganze Zahl in Wort über Alphabet
+
+=head4 Synopsis
+
+    $word = $this->intToWord($n);
+    $word = $this->intToWord($n,$alphabet);
+
+=head4 Description
+
+Wandele positive ganze Zahl $n in ein Wort über dem Alphabet
+$alphabet und liefere dieses zurück. Für 0 liefere
+einen Leerstring.
+
+Das Alphabet, über welchem die Worte gebildet werden, wird in Form
+einer Zeichenkette angegeben, in der jedes Zeichen einmal
+vorkommt. Per Default wird das Alphabet
+
+    'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
+
+verwendet. Die Funktion implementiert folgende Abbildung:
+
+    0 -> ''
+    1 -> 'A'
+    2 -> 'B'
+    
+    ...
+    26 -> 'Z'
+    27 -> 'AA'
+    28 -> 'AB'
+    ...
+    52 -> 'AZ'
+    53 -> 'BA'
+    ...
+
+=head4 Returns
+
+Zeichenkette
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub intToWord {
+    my $this = shift;
+    my $n = shift;
+    my $alphabet = shift || 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
+
+    my $l = length $alphabet;
+
+    my $word = '';
+    my $m = $n; # warum dies?
+
+    while ($m) {
+        my $mod = $m%$l;
+        $word = substr($alphabet,$mod-1,1).$word;
+        $m = POSIX::floor($m/$l);
+        $m -= 1 if $mod == 0;
+    }
+
+    return $word;
+}
+
+# -----------------------------------------------------------------------------
+
 =head2 Zeitdarstellung
 
 =head3 epochToDuration() - Wandele Sekunden in (lesbare) Angabe einer Dauer
@@ -325,7 +390,7 @@ sub stringToKeyVal {
 
 =head1 VERSION
 
-1.104
+1.105
 
 =head1 AUTHOR
 
