@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.104;
+our $VERSION = 1.105;
 
 use Prty::Option;
 use Prty::FileHandle;
@@ -1518,19 +1518,60 @@ sub newer {
 
 =head4 Synopsis
 
-    $class->rename($oldPath,$newPath);
+    $class->rename($oldPath,$newPath,@opt);
 
 =head4 Description
 
 Benenne Pfad $oldPath in $newPath um. Die Methode liefert keinen
 Wert zurück.
 
+=head4 Options
+
+=over 4
+
+=item -overwrite => $bool (Default: 1)
+
+Wenn gesetzt, wird die Datei $newPath überschrieben, falls sie
+existiert. Wenn nicht gesetzt, wird eine Exception geworfen,
+falls sie existiert.
+
+=back
+
 =cut
 
 # -----------------------------------------------------------------------------
 
 sub rename {
-    my ($class,$oldPath,$newPath) = @_;
+    my $class = shift;
+    my $oldPath = shift;
+    my $newPath = shift;
+    # @_: @opt
+
+    # Optionen
+
+    my $overwrite = 1;
+    my $recursive = 0;
+
+    Prty::Option->extract(\@_,
+        -overwrite=>\$overwrite,
+        -recursive=>\$recursive,
+    );
+
+    if (!$overwrite && -e $newPath) {
+        $class->throw(
+            q{PATH-00099: Zieldatei existiert bereits},
+            Path=>$newPath,
+        );
+    }
+
+    # Erzeuge Verzeichnis, wenn nötig
+
+    if ($recursive) {
+        my $dir = (Prty::Path->split($newPath))[0];
+        if ($dir && !-d $dir) {
+            $class->mkdir($dir,-recursive=>1);
+        }
+    }
 
     CORE::rename $oldPath,$newPath or do {
         $class->throw(
@@ -1717,7 +1758,7 @@ sub symlinkRelative {
 
 =head1 VERSION
 
-1.104
+1.105
 
 =head1 AUTHOR
 
