@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.104;
+our $VERSION = 1.105;
 
 use Encode::Guess ();
 use Encode ();
@@ -463,7 +463,7 @@ sub removeIndentationNl {
 
 =head2 Kommentare
 
-=head3 removeComments() - Entferne Kommentare aus einem Quelltext
+=head3 removeComments() - Entferne Kommentare aus Quelltext
 
 =head4 Synopsis
 
@@ -595,9 +595,118 @@ sub removeComments {
 
 # -----------------------------------------------------------------------------
 
+=head2 Umbruch
+
+=head3 wrap() - Umbreche Fließtext
+
+=head4 Synopsis
+
+    $text = $class->wrap($text,@opt);
+
+=head4 Description
+
+Umbreche Fließext $text, so dass die Zeilenlänge $width möglichst
+nicht überschritten wird. Sie kann überschritten werden, wenn ein
+Wort länger als $width ist, sonst ist die Zeilenlänge <= $width.
+
+Whitespace:
+
+=over 2
+
+=item *
+
+Whitespace am Anfang und am Ende von $text wird entfernt
+
+=item *
+
+Folgen von Whitespace-Zeichen innerhalb von $text werden zu
+einem Whitespace-Zeichen reduziert
+
+=back
+
+Paragraphen:
+
+Ist der Text in Paragraphen organisiert und soll dies erhalten
+bleiben, muss jeder Paragraph einzeln umbrochen werden.
+
+=head4 Options
+
+=over 4
+
+=item -width => $n (Default: 70)
+
+Maximale Zeilenbreite des resultierenden Fließtextes (sofern kein
+einzelnes Wort länger als die Zeilenbreite ist).
+
+=back
+
+=head4 Example
+
+Maximale Zeilenlänge auf 12 Zeichen begrenzen:
+
+    $txt = "Dies ist ein Test mit einem kurzen Text.";
+    $txt = Prty::String->wrap($txt,-width=>12);
+    # =>
+    Dies ist ein
+    Test mit
+    einem kurzen
+    Text.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub wrap {
+    my $class = shift;
+    my $text = shift;
+    # @_: @opt
+
+    # Optionen
+
+    my $width = 70;
+    if (@_) {
+        Prty::Option->extract(\@_,
+            -width=>\$width,
+        );
+    }
+
+    $text =~ s/^\s+//;
+    $text =~ s/\s+$//;
+
+    my @words = split /\s+/,$text;
+
+    my $newText = '';
+    my $line = '';
+    while (my $word = shift @words) {
+        my $l = length $line;
+        if ($l == 0) {
+            if (length($word) > $width) {
+                $newText .= "$word\n";
+            }
+            else {
+                $line .= $word;
+            }
+        }
+        elsif ($l+length($word)+1 > $width) {
+            $newText .= "$line\n";
+            $line = $word;
+        }
+        else {
+            $line .= " $word";
+        }
+    }        
+    if ($line) {
+        $newText.= $line;
+    }
+
+    return $newText;
+}
+
+# -----------------------------------------------------------------------------
+
 =head1 VERSION
 
-1.104
+1.105
 
 =head1 AUTHOR
 
