@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.104;
+our $VERSION = 1.105;
 
 use POSIX ();
 use Time::Local ();
@@ -447,6 +447,42 @@ sub dayName {
 
 # -----------------------------------------------------------------------------
 
+=head3 monthName() - Monatsname
+
+=head4 Synopsis
+
+    $str = $ti->monthName;
+
+=head4 Description
+
+Liefere Monatsnamen (Januar, Februar, ..., Dezember).
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+our @MonthName = qw(
+    Januar
+    Februar
+    März
+    April
+    Mai
+    Juni
+    Juli
+    August
+    September
+    Oktober
+    November
+    Dezember
+);
+
+sub monthName {
+    my $self = shift;
+    return $MonthName[$self->month-1];
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 dayOfWeek() - Wochentagsnummer
 
 =head4 Synopsis
@@ -1318,7 +1354,7 @@ sub diff {
 
 =head1 VERSION
 
-1.104
+1.105
 
 =head1 AUTHOR
 
